@@ -25,6 +25,7 @@ import itertools
 import re
 
 from blingalytics import sources, widgets
+from blingalytics.caches import cache_connection
 
 
 DEFAULT_CACHE_TIME = 60 * 30
@@ -145,7 +146,7 @@ class Report(object):
     Here is a relatively simple example of a report definition::
 
         from blingalytics import base, formats, widgets
-        from blingalytics.sources import database, derived, key_range
+        from blingalytics.sources import sqlalchemy_orm, derived, key_range
 
         class RevenueReport(base.Report):
             display_name = 'Company Revenue'
@@ -153,23 +154,23 @@ class Report(object):
             category = 'business'
             cache_time = 60 * 60 * 3 # three hours
 
-            database_entity = 'project.models.reporting.RevenueModel'
+            sqlalchemy_entity = 'project.models.reporting.RevenueModel'
             keys = ('product_id', key_range.SourceKeyRange)
             columns = [
-                ('product_id', database.GroupBy('product_id',
+                ('product_id', sqlalchemy_orm.GroupBy('product_id',
                     format=formats.Integer(label='ID', grouping=False), footer=False)),
-                ('product_name', database.Lookup('project.models.products.Product',
+                ('product_name', sqlalchemy_orm.Lookup('project.models.products.Product',
                     'name', 'product_id', format=formats.String)),
-                ('revenue', database.Sum('purchase_revenue', format=formats.Bling)),
-                ('_cost_of_revenue', database.First('product_cost')),
+                ('revenue', sqlalchemy_orm.Sum('purchase_revenue', format=formats.Bling)),
+                ('_cost_of_revenue', sqlalchemy_orm.First('product_cost')),
                 ('gross_margin', derived.Value(
                     lambda row: (row['revenue'] - row['_cost_of_revenue']) * \\
                     Decimal('100.00') / row['revenue'], format=formats.Bling)),
             ]
             filters = [
-                ('delivered', database.QueryFilter(
+                ('delivered', sqlalchemy_orm.QueryFilter(
                     lambda entity: entity.is_delivered == True)),
-                ('online_only', database.QueryFilter(
+                ('online_only', sqlalchemy_orm.QueryFilter(
                     lambda entity, user_input: entity.is_online_purchase == user_input,
                     widget=widgets.Checkbox(label='Online Purchase'))),
             ]
@@ -398,6 +399,7 @@ class Report(object):
         # Return the finalized footer
         return self._footer
 
+    @cache_connection
     def run_report(self):
         """
         Processes the report data and stores it in cache.
@@ -411,7 +413,9 @@ class Report(object):
         self._init_footer()
         self.cache.create_instance(self.unique_id[0], self.unique_id[1],
             self._get_rows(), self._get_footer, self.cache_time)
+        self.report_finalize()
 
+    @cache_connection
     def kill_cache(self, full=False):
         """
         By default, this removes or invalidates (depending on the cache store
@@ -427,6 +431,7 @@ class Report(object):
             return
         self.cache.kill_instance_cache(*self.unique_id)
 
+    @cache_connection
     def is_report_started(self):
         """
         If :meth:`run_report` is currently running, this returns ``True``;
@@ -434,6 +439,7 @@ class Report(object):
         """
         return self.cache.is_instance_started(*self.unique_id)
 
+    @cache_connection
     def is_report_finished(self):
         """
         If :meth:`run_report` has completed and there is a current cached copy
@@ -441,12 +447,14 @@ class Report(object):
         """
         return self.cache.is_instance_finished(*self.unique_id)
 
+    @cache_connection
     def report_row_count(self):
         """
         Returns the total number of rows in this report instance.
         """
         return self.cache.instance_row_count(*self.unique_id)
 
+    @cache_connection
     def report_timestamp(self):
         """
         Returns the timestamp when the report instance was originally computed
@@ -492,6 +500,7 @@ class Report(object):
             header_row.append(header_info)
         return header_row
 
+    @cache_connection
     def report_rows(self, selected_rows=None, sort=None, limit=None, offset=0, format='html'):
         """
         Returns the requested rows for the report from cache. There are a
@@ -544,6 +553,13 @@ class Report(object):
 
         return formatted_rows
 
+    def report_finalize(self):
+        """
+        Cleans up source columns.
+        """
+        [c.finalize() for c in self.columns_dict.values()]
+
+    @cache_connection
     def report_footer(self, format='html'):
         """
         Returns the computed footer row for the report. There is one argument
