@@ -6,7 +6,7 @@ import blingalytics
 from blingalytics import base, caches, formats, widgets
 from mock import Mock
 
-from test import reports
+from test import reports_sqlalchemy
 
 
 class TestReportUtilities(unittest.TestCase):
@@ -57,7 +57,7 @@ class TestReportUtilities(unittest.TestCase):
 class TestReportBase(unittest.TestCase):
     def setUp(self):
         self.mock_cache = Mock(spec=caches.Cache)
-        self.report = reports.BasicDatabaseReport(self.mock_cache)
+        self.report = reports_sqlalchemy.BasicDatabaseReport(self.mock_cache)
 
     def test_unique_ids(self):
         # Repeatable
@@ -302,6 +302,8 @@ class TestFormats(unittest.TestCase):
 
         format = formats.String(label='Trunc', truncate=10)
         self.assertEqual(format.format_html('Truncated text goes here'), 'Truncat...')
+        format = formats.String(label='Trunc', truncate=2)
+        self.assertEqual(format.format_html('Truncated text goes here'), 'Tr')
 
         format = formats.String(label='Title', title=True)
         self.assertEqual(format.format_html('title cased text'), 'Title Cased Text')
@@ -345,7 +347,6 @@ class TestWidgets(unittest.TestCase):
         self.assertEqual(widget.form_name, 'report_widget')
         self.assertEqual(widget.clean(''), None)
         self.assertEqual(widget.clean(12), 12)
-        self.assertRaises(NotImplementedError, widget.render)
 
         # With required
         widget = widgets.Widget(required=True)
